@@ -9,91 +9,42 @@
 #' Note this function is intended to be used interactively when deciding how often to
 #' schedule the orchestrator. Programmatic use is not recommended.
 #'
-#' @param schedule schedule data.frame created by `build_schedule()`
-#' @inheritParams check_pipelines
+#' @param schedule MaestroSchedule object created by `build_schedule()`
+#' @inheritParams get_pipeline_run_sequence
 #'
 #' @return frequency string
 #' @export
 #'
 #' @examples
 #'
-#' suggest_orch_frequency(example_schedule)
+#' if (interactive()) {
+#'   pipeline_dir <- tempdir()
+#'   create_pipeline("my_new_pipeline", pipeline_dir, open = FALSE)
+#'   schedule <- build_schedule(pipeline_dir = pipeline_dir)
+#'   suggest_orch_frequency(schedule)
+#' }
 suggest_orch_frequency <- function(schedule, check_datetime = lubridate::now(tzone = "UTC")) {
 
-  # Check that schedule is a data.frame
-  if (!"data.frame" %in% class(schedule)) {
+  # Check that schedule is a MaestroSchedule
+  if (!"MaestroSchedule" %in% class(schedule)) {
     cli::cli_abort(
-      c("Schedule must be a data.frame and not an object of class {class(schedule)}.",
+      c("Schedule must be an object of {.cls MaestroSchedule} and not an object of class {.cls {class(schedule)}}.",
         "i" = "Use {.fn build_schedule} to create a valid schedule."),
       call = rlang::caller_env()
     )
   }
 
-  # Check that schedule has at least one row
+  schedule <- schedule$get_schedule() |>
+    dplyr::filter(!skip)
+
   if (nrow(schedule) == 0) {
+
     cli::cli_abort(
-      c("Empty schedule. Schedule must have at least one row.",
-        "i" = "Use {.fn build_schedule} to create a valid schedule."),
-      call = rlang::caller_env()
-    )
-  }
-
-  if (!"frequency" %in% names(schedule)) {
-    cli::cli_abort(
-      c("Schedule is missing required column 'frequency'.",
-        "i" = "Use {.fn build_schedule} to create a valid schedule."
-      ),
-      call = rlang::caller_env()
-    )
-  }
-
-  if (typeof(schedule$frequency) != "character") {
-    cli::cli_abort(
-      c("Schedule columns {.code frequency} must have type 'character'.",
-        "i" = "Use {.fn build_schedule} to create a valid schedule."),
-      call = rlang::caller_env()
-    )
-  }
-
-  if (!"start_time" %in% names(schedule)) {
-    cli::cli_abort(
-      c("Schedule is missing required column 'start_time'.",
-        "i" = "Use {.fn build_schedule} to create a valid schedule."
-      ),
-      call = rlang::caller_env()
-    )
-  }
-
-  if (!"POSIXct" %in% class(schedule$start_time)) {
-    cli::cli_abort(
-      c("Schedule columns {.code start_time} must have type 'POSIXct'.",
-        "i" = "Use {.fn build_schedule} to create a valid schedule."),
-      call = rlang::caller_env()
-    )
-  }
-
-  if ("skip" %in% names(schedule)) {
-
-    if (typeof(schedule$skip) != "logical") {
-      cli::cli_abort(
-        c("Schedule columns {.code skip} must have type 'logical'.",
-          "i" = "Use {.fn build_schedule} to create a valid schedule."),
-        call = rlang::caller_env()
+      c(
+        "No pipelines in schedule after removing skipped pipelines.",
+        "i" = "Remove `maestroSkip` tags to get a suggested frequency."
       )
-    }
-
-    schedule <- schedule |>
-      dplyr::filter(!skip)
-
-    if (nrow(schedule) == 0) {
-
-      cli::cli_abort(
-        c(
-          "No pipelines in schedule after removing skipped pipelines.",
-          "i" = "Remove `maestroSkip` tags to get a suggested frequency."
-        )
-      )
-    }
+    )
   }
 
   sch_secs <- purrr::map_int(
@@ -101,13 +52,6 @@ suggest_orch_frequency <- function(schedule, check_datetime = lubridate::now(tzo
     purrr::possibly(convert_to_seconds, otherwise = NA, quiet = TRUE)
   )
 
-  if (any(is.na(sch_secs))) {
-    cli::cli_abort(
-      c("There are invalid time units.",
-        "i" = "Use {.fn build_schedule} to create a valid schedule.")
-    )
-  }
-
   # If the minimum schedule seconds is lte 15 minutes, return the corresponding frequency
   if (min(sch_secs, na.rm = TRUE) <= (60 * 15)) {
     return(schedule$frequency[[which.min(sch_secs)]])
